@@ -4,11 +4,10 @@
 
 from dataloader.pipeline.datapipe import ProxyDataPipe
 from dataloader.util.batch import RepeatInBatch
-from dataloader.util.to_tensor import to_tf_tensor
 
 
 class Batch(ProxyDataPipe):
-    def __init__(self, datapipe, batch_size, drop_last, repeat_in_batch=None, to_tensor_func=to_tf_tensor):
+    def __init__(self, datapipe, batch_size, drop_last, fn_to_tensor, repeat_in_batch=None):
         super().__init__(datapipe)
 
         self.batch_size = batch_size
@@ -18,9 +17,10 @@ class Batch(ProxyDataPipe):
         if repeat_in_batch is None or not isinstance(repeat_in_batch, RepeatInBatch):
             self.repeat_in_batch = RepeatInBatch(kind='no')
 
-        self._to_tensor_func = to_tensor_func
-        if self._to_tensor_func is None:
-            self._to_tensor_func = to_tf_tensor
+        self._fn_to_tensor = fn_to_tensor
+
+        if self._fn_to_tensor is None:
+            raise ValueError('to_tensor_func should not be None')
 
     def __len__(self):
         sz = len(self.datapipe) if self.drop_last else len(self.datapipe) + self.batch_size - 1
@@ -34,15 +34,15 @@ class Batch(ProxyDataPipe):
 
             if len(batch) == self.batch_size:
                 batch = self.repeat_in_batch.repeat(batch)
-                yield self._to_tensor_func(batch)
+                yield self._fn_to_tensor(batch)
 
                 del batch[:]
 
         if len(batch) == self.batch_size:
             batch = self.repeat_in_batch.repeat(batch)
-            yield self._to_tensor_func(batch)
+            yield self._fn_to_tensor(batch)
 
         if len(batch) > 0 and not self.drop_last:
             batch = self.repeat_in_batch.repeat(batch)
-            yield self._to_tensor_func(batch)
+            yield self._fn_to_tensor(batch)
 
